/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.mailcreator;

import java.util.List;
import javax.mail.Message.RecipientType;
import com.google.gson.JsonObject;
import com.openexchange.exception.OXException;

/**
 * {@link MailCreatorService}
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since v2.4.0
 */
public interface MailCreatorService {

    JsonObject createBlankMail();

    JsonObject createBlankOutMail(String lang, int templId) throws OXException;

    JsonObject createBlankGuestMail(String lang, int templId, String host, int userid, int cid) throws OXException;

    JsonObject createBlankGuestMail(String lang, int templId, String messageID, String host, int userid, int cid) throws OXException;

    JsonObject addPlainText(JsonObject email, String data);

    JsonObject addURL(JsonObject email, String data);

    JsonObject addTo(JsonObject mail, String name, String email, RecipientType type);

    JsonObject addTo(JsonObject mail, String name, String email);

    JsonObject addCC(JsonObject mail, String name, String email);

    JsonObject addBCC(JsonObject mail, String name, String email);

    JsonObject addFrom(JsonObject mail, String name, String email);

    JsonObject addSubject(JsonObject mail, String subject);

    JsonObject setContent(JsonObject mail, String content);

    JsonObject noSave(JsonObject email);

    JsonObject getOxPasswordEmail(String to, String sendername, String from, String from2, String password, String lang, int templId, String host, int userid, int cid) throws OXException;

    JsonObject getPasswordEmail(String to, String sendername, String from, String from2, String password, String lang, int templId, String guestmessage, String host, int userid, int cid) throws OXException;

    JsonObject getResetEmail(String to, List<String> from, String password, String lang, int templId, String host, int userid, int cid) throws OXException;

    List<String> getFromAddress(String name, String email, int userid, int cid) throws OXException;

}
